﻿#pragma once
/**
* @file StovePCSDK.h
* @brief StovePCSDK 헤더파일
* @details StovePCSDK에서 제공하는 함수를 선언합니다.
*/
#ifndef STOVEPCCALLBACK_H_
#define STOVEPCCALLBACK_H_

#include "StovePCDefine.h"


/*!
*  @struct StovePCCallback
*  @brief Stove API 호출시 응답받는 콜백을 설정하는 구조체입니다.
*/
struct StovePCCallback
{
    /// StovePCSDK 에서 에러발생시 호출되는 콜백 함수 포인터 
    void(*OnError)(const StovePCError error);

    /// Init API 호출시 응답받는 콜백 함수 포인터
    void(*OnInitComplete)();

    /// GetToken API 호출시 응답받는 콜백 함수 포인터 
    void(*OnToken)(const StovePCToken token);

    /// GetUser API 호출시 응답받는 콜백 함수 포인터
    void(*OnUser)(const StovePCUser user);

    /// GetOwnership API 호출시 응답받는 콜백 함수 포인터
    void(*OnOwnership)(int size, StovePCOwnership* ownership);

    /// GetStat API 호출시 응답받는 콜백 함수 포인터
    void(*OnStat)(const StovePCStat stat);

    /// SetStat API 호출시 응답받는 콜백 함수 포인터
    void(*OnSetStat)(const StovePCStatValue statValue);

    /// GetAchievment API 호출시 응답받는 콜백 함수 포인터
    void(*OnAchievement)(const StovePCAchievement achievement);

    /// GetAchievments API 호출시 응답받는 콜백 함수 포인터
    void(*OnAllAchievement)(int size, StovePCAchievement* achievement);

    /// GetRank API 호출시 응답받는 콜백 함수 포인터
    void(*OnRank)(int size, StovePCRank* rank, unsigned int rankTotalCount);

    /// GetAutoPopup API 호출시 응답받는 콜백 함수 포인터
    void(*OnAutoPopup)(int size, StovePCAutoPopup* autoPopup, int headerSize, StovePCPopupRequestHeader* header);

    /// GetManualPopup API 호출시 응답받는 콜백 함수 포인터
    void(*OnManualPopup)(int size, StovePCManualPopup* manualPopup, int headerSize, StovePCPopupRequestHeader* header);

    /// GetNewsPopup API 호출시 응답받는 콜백 함수 포인터
    void(*OnNewsPopup)(StovePCNewsPopup newsPopup, int headerSize, StovePCPopupRequestHeader* header);

    /// GetCouponPopup API 호출시 응답받는 콜백 함수 포인터
    void(*OnCouponPopup)(StovePCCouponPopup couponPopup, int headerSize, StovePCPopupRequestHeader* header);

    /// GetCommunityPopup API 호출시 응답받는 콜백 함수 포인터
    void(*OnCommunityPopup)(StovePCCommunityPopup communityPopup, int cookieSize, StovePCPopupRequestCookie* cookie);

    /// StashEventLog API 호출시 응답받는 콜백 함수 포인터
    void(*OnStashCustomEvent)(const StovePCCustomEvent customEvent, int parameterSize, StovePCCustomEventParameter* parameter);

    /// PCSDK 내부에서 토큰 갱신시 응답받는 콜백 함수 포인터 
    void(*OnRenewToken)(const StovePCToken token);

    /// PCSDK 내부에서 게임 과몰입시 응답받는 콜백 함수 포인터 
    void(*OnOverImmersion)(const StovePCOverImmersion overImmersion);

    /// PCSDK 내부에서 셧다운 알림 발생시 응답받는 콜백 함수 포인터 
    void(*OnShutdown)(const StovePCShutdown shutdown);

    // IAP
    /// FetchShopCategories API 호출시  응답받는 콜백 함수 포인터
    void(*OnFetchShopCategories)(const int size, StovePCShopCategory* categories);

    /// FetchProducts API 호출시  응답받는 콜백 함수 포인터
    void(*OnFetchProducts)(const int size, StovePCProduct* products);

    /// StartPurchase API 호출시  응답받는 콜백 함수 포인터
    void(*OnStartPurchase)(StovePCPurchase purchase);

    /// ConfirmPurchase API 호출시  응답받는 콜백 함수 포인터
    void(*OnConfirmPurchase)(const int size, StovePCPurchaseProduct* purchaseProducts, bool status, char* shopKey);

    /// FetchInventory API 호출시  응답받는 콜백 함수 포인터
    void(*OnFetchInventory)(const int size, StovePCInventoryItem* inventoryItems);
    // IAP
};

#endif